#ifndef EVAL_SLAM_PARSER_H
#define EVAL_SLAM_PARSER_H

#include <string>
#include <vector>
#include <iostream>

///Struct containing default or specified settings
struct parser_params {
    ///Path to dataset
    std::string path = "../res/dictionary.txt";
    ///Run both version and print comparsion results
    bool use_ekf = false;
};

class Parser {
private:
    /// Checks for --help or -h switch
    /// \param string to be parsed
    /// \return true if detected, false otherwise
    bool contains_help(std::string const &argument);

    /// Checks for --odometry or -o switch
    /// \param string to be parsed
    /// \return true if detected, false otherwise
    bool contains_use_ekf(std::string const &argument);

    ///Prints help on standard output
    void print_help();

    ///Prints error on standard error output
    void print_error();

public:
    /// Processes command line arguments
    /// \param argc
    /// \param argv
    /// \return true if --help or -h is detected, false otherwise
    bool process_arguments(int argc, char **argv);

    ///Struct containing default or specified settings
    parser_params init;

};


#endif //EVAL_SLAM_PARSER_H
